@@ -14,6 +14,7 @@ import (
 
 	"github.com/superfly/flyctl/flyctl"
 	"github.com/superfly/flyctl/internal/buildinfo"
+	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/filemu"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/sentry"
@@ -50,6 +51,7 @@ func StartDaemon(ctx context.Context) (*Client, error) {
 		versionNum := versionPre[0].VersionNum
 		env = append(env, fmt.Sprintf("FLY_DEV_VERSION_NUM=%d", versionNum))
 	}
+	env = append(env, fmt.Sprintf("FLY_API_TOKEN=%s", config.FromContext(ctx).AccessToken))
 
 	cmd.Env = env
 	setSysProcAttributes(cmd)
