@@ -12,6 +12,7 @@ import (
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
+	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -30,6 +31,7 @@ sent, and the user will be pending until they respond.
 
 	cmd.Args = cobra.MaximumNArgs(2)
 
+	flag.Add(cmd, flag.JSONOutput())
 	return cmd
 }
 
