@@ -11,6 +11,7 @@ import (
 	"os/exec"
 	"path/filepath"
 	"testing"
+	"time"
 
 	"github.com/BurntSushi/toml"
 	"github.com/google/shlex"
@@ -29,6 +30,7 @@ type FlyctlTestEnv struct {
 	primaryRegion       string
 	otherRegions        []string
 	cmdHistory          []*FlyctlResult
+	noHistoryOnFail     bool
 }
 
 func (f *FlyctlTestEnv) OrgSlug() string {
@@ -53,28 +55,31 @@ func (f *FlyctlTestEnv) OtherRegions() []string {
 
 func NewTestEnvFromEnv(t testing.TB) *FlyctlTestEnv {
 	tempDir := socketSafeTempDir(t)
+	_, noHistoryOnFail := os.LookupEnv("FLY_PREFLIGHT_TEST_NO_PRINT_HISTORY_ON_FAIL")
 	env := NewTestEnvFromConfig(t, TestEnvConfig{
-		homeDir:       tempDir,
-		workDir:       tempDir,
-		flyctlBin:     os.Getenv("FLY_PREFLIGHT_TEST_FLYCTL_BINARY_PATH"),
-		orgSlug:       os.Getenv("FLY_PREFLIGHT_TEST_FLY_ORG"),
-		primaryRegion: primaryRegionFromEnv(),
-		otherRegions:  otherRegionsFromEnv(),
-		accessToken:   os.Getenv("FLY_PREFLIGHT_TEST_ACCESS_TOKEN"),
-		logLevel:      os.Getenv("FLY_PREFLIGHT_TEST_LOG_LEVEL"),
+		homeDir:         tempDir,
+		workDir:         tempDir,
+		flyctlBin:       os.Getenv("FLY_PREFLIGHT_TEST_FLYCTL_BINARY_PATH"),
+		orgSlug:         os.Getenv("FLY_PREFLIGHT_TEST_FLY_ORG"),
+		primaryRegion:   primaryRegionFromEnv(),
+		otherRegions:    otherRegionsFromEnv(),
+		accessToken:     os.Getenv("FLY_PREFLIGHT_TEST_ACCESS_TOKEN"),
+		logLevel:        os.Getenv("FLY_PREFLIGHT_TEST_LOG_LEVEL"),
+		noHistoryOnFail: noHistoryOnFail,
 	})
 	return env
 }
 
 type TestEnvConfig struct {
-	homeDir       string
-	workDir       string
-	flyctlBin     string
-	orgSlug       string
-	primaryRegion string
-	otherRegions  []string
-	accessToken   string
-	logLevel      string
+	homeDir         string
+	workDir         string
+	flyctlBin       string
+	orgSlug         string
+	primaryRegion   string
+	otherRegions    []string
+	accessToken     string
+	logLevel        string
+	noHistoryOnFail bool
 }
 
 func NewTestEnvFromConfig(t testing.TB, cfg TestEnvConfig) *FlyctlTestEnv {
@@ -106,6 +111,7 @@ func NewTestEnvFromConfig(t testing.TB, cfg TestEnvConfig) *FlyctlTestEnv {
 		homeDir:             cfg.homeDir,
 		workDir:             cfg.workDir,
 		originalAccessToken: cfg.accessToken,
+		noHistoryOnFail:     cfg.noHistoryOnFail,
 	}
 	testEnv.verifyTestOrgExists()
 	t.Cleanup(func() {
@@ -151,7 +157,7 @@ func (f *FlyctlTestEnv) FlyContextAndConfig(ctx context.Context, cfg FlyCmdConfi
 	argsStr := fmt.Sprintf(flyctlCmd, vals...)
 	args, err := shlex.Split(argsStr)
 	if err != nil {
-		f.t.Fatalf("failed to parse argStr: %s error: %v", argsStr, err)
+		f.Fatalf("failed to parse argStr: %s error: %v", argsStr, err)
 	}
 	testIostreams, stdIn, stdOut, stdErr := iostreams.Test()
 	res := &FlyctlResult{
@@ -170,7 +176,7 @@ func (f *FlyctlTestEnv) FlyContextAndConfig(ctx context.Context, cfg FlyCmdConfi
 	cmd.Stderr = testIostreams.ErrOut
 	err = cmd.Start()
 	if err != nil {
-		f.t.Fatalf("failed to start command: %s [error]: %s", res.cmdStr, err)
+		f.Fatalf("failed to start command: %s [error]: %s", res.cmdStr, err)
 	}
 	err = cmd.Wait()
 	if err == nil {
@@ -178,7 +184,7 @@ func (f *FlyctlTestEnv) FlyContextAndConfig(ctx context.Context, cfg FlyCmdConfi
 	} else if exitErr, ok := err.(*exec.ExitError); ok {
 		res.exitCode = exitErr.ExitCode()
 	} else {
-		f.t.Fatalf("unexpected error waiting on command: %s [error]: %v", res.cmdStr, err)
+		f.Fatalf("unexpected error waiting on command: %s [error]: %v", res.cmdStr, err)
 	}
 	f.cmdHistory = append(f.cmdHistory, res)
 	if !cfg.NoAssertSuccessfulExit {
@@ -197,7 +203,7 @@ func (f *FlyctlTestEnv) ResetAuthAccessToken() {
 
 func (f *FlyctlTestEnv) DebugPrintHistory() {
 	f.t.Helper()
-	if f.Failed() {
+	if f.Failed() || f.noHistoryOnFail {
 		return
 	}
 	for i, r := range f.cmdHistory {
@@ -212,10 +218,10 @@ func (f *FlyctlTestEnv) verifyTestOrgExists() {
 	var orgMap map[string]string
 	err := json.Unmarshal(result.stdOut.Bytes(), &orgMap)
 	if err != nil {
-		f.t.Fatalf("failed to parse json: %v [output]: %s\n", err, result.stdOut.String())
+		f.Fatalf("failed to parse json: %v [output]: %s\n", err, result.stdOut.String())
 	}
 	if _, present := orgMap[f.orgSlug]; !present {
-		f.t.Fatalf("could not find org with name '%s' in `%s` output: %s", f.orgSlug, result.cmdStr, result.stdOut.String())
+		f.Fatalf("could not find org with name '%s' in `%s` output: %s", f.orgSlug, result.cmdStr, result.stdOut.String())
 	}
 }
 
@@ -234,12 +240,13 @@ func (f *FlyctlTestEnv) CreateRandomAppMachines() string {
 }
 
 func (f *FlyctlTestEnv) MachinesList(appName string) []*api.Machine {
+	time.Sleep(800 * time.Millisecond) // fly m list is eventually consistent, yay!
 	cmdResult := f.Fly("machines list --app %s --json", appName)
 	cmdResult.AssertSuccessfulExit()
 	var machList []*api.Machine
 	err := json.Unmarshal(cmdResult.stdOut.Bytes(), &machList)
 	if err != nil {
-		f.t.Fatalf("failed to unmarshal machines list json for app %s:\n%s", appName, cmdResult.stdOut.String())
+		f.Fatalf("failed to unmarshal machines list json for app %s:\n%s", appName, cmdResult.stdOut.String())
 	}
 	return machList
 }
@@ -248,7 +255,7 @@ func (f *FlyctlTestEnv) VolumeList(appName string) []*api.Volume {
 	cmdResult := f.Fly("volume list --app %s --json", appName)
 	var list []*api.Volume
 	if err := json.Unmarshal(cmdResult.stdOut.Bytes(), &list); err != nil {
-		f.t.Fatalf("failed to unmarshal machines list json for app %s:\n%s", appName, cmdResult.stdOut.String())
+		f.Fatalf("failed to unmarshal machines list json for app %s:\n%s", appName, cmdResult.stdOut.String())
 	}
 	return list
 }
